﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace PublicationManager
{
    public partial class ManyToManyBindingForm : Form
    {
        public ManyToManyBindingForm()
        {
            InitializeComponent();
        }
        private void OnFormLoad(object sender, EventArgs e)
        {
            // Get the data
            PubsDataAccess.GetPublicationData(m_PubsDataSet);
            // Set the grid data sources
            m_AuthorsGrid.DataSource = m_AuthorsBindingSource;
            m_TitlesGrid.DataSource = m_TitlesBindingSource;
            // Set the binding source data sources
            m_AuthorsBindingSource.DataSource = m_PubsDataSet;
            m_AuthorsBindingSource.DataMember = m_PubsDataSet.authors.TableName;
            m_TitlesBindingSource.DataSource = m_PubsDataSet;
            m_TitlesBindingSource.DataMember = m_PubsDataSet.titles.TableName;
            m_TitleAuthorBindingSource.DataSource = m_AuthorsBindingSource;
            m_TitleAuthorBindingSource.DataMember = "FK_titleauthor_authors";
            m_PublishersBindingSource.DataSource = m_PubsDataSet.publishers;
            // Set the simple binding on the publisher textbox
            m_PublisherTextBox.DataBindings.Add("Text", m_PublishersBindingSource, "pub_name");
            // Hook up event handlers on the binding sources
            m_TitlesBindingSource.CurrentChanged += OnCurrentTitleChanged;
            m_TitleAuthorBindingSource.BindingComplete += OnTitleAuthorBindingComplete;
            m_TitleAuthorBindingSource.ListChanged += OnTitleAuthorListChanged;
            BindTitles();
        }

        void OnTitleAuthorListChanged(object sender, ListChangedEventArgs e)
        {
            BindTitles();
        }

        private void OnTitleAuthorBindingComplete(object sender, BindingCompleteEventArgs e)
        {
            BindTitles();
        }

        private void BindTitles()
        {
            string filterString = string.Empty;
            // Loop through the related child rows in the join table
            // and add a filter criteria to the filter string
            foreach (DataRowView row in m_TitleAuthorBindingSource.List)
            {
                if (filterString != string.Empty)
                    filterString += " OR ";
                filterString += "title_id = '" + row["title_id"] + "'";
            }
            // Set as the filter string on the titles source
            m_TitlesBindingSource.Filter = filterString;
        }

        private void OnCurrentTitleChanged(object sender, EventArgs e)
        {
            // Get the current row from the titles source
            DataRowView rowView = m_TitlesBindingSource.Current as DataRowView;
            // Cast to the strongly typed row type
            PubsDataSet.titlesRow row = rowView.Row as PubsDataSet.titlesRow;
            // Set the filter criteria on the publishers source
            m_PublishersBindingSource.Filter = "pub_id = '" + row.pub_id + "'";

            // Alternative approach - navigate through the relation
            m_PublisherTextBox.Text = row.publishersRow.pub_name;
        }
    }
}